@@ -19,3 +19,7 @@ type tFooTest int
 func fFooTest() {}
 
 func (*tFooTest) fooFooTest() {}
+
+// Below blank declaration has no godoc, but it should be ignored.
+
+var _ = 0
